You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by pa...@apache.org on 2011/12/08 11:59:49 UTC

svn commit: r1211823 - in /directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor: ./ controller/ controller/actions/ view/ view/editors/schema/ view/search/ view/views/ view/wizards/

Author: pamarcelot
Date: Thu Dec  8 10:59:48 2011
New Revision: 1211823

URL: http://svn.apache.org/viewvc?rev=1211823&view=rev
Log:
Fix for DIRSTUDIO-655 (Switch usage of SWT MessageBox to JFace MessageDialog for info, warning and error dialogs).

Modified:
    directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/PluginUtils.java
    directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/HierarchyViewController.java
    directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/ProblemsViewController.java
    directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/SchemaViewController.java
    directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/actions/OpenElementAction.java
    directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/actions/OpenTypeHierarchyAction.java
    directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/ViewUtils.java
    directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/editors/schema/SchemaEditorOverviewPage.java
    directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/search/SearchPage.java
    directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/views/SearchView.java
    directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportProjectsWizard.java
    directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportSchemasAsOpenLdapWizard.java
    directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportSchemasAsXmlWizard.java
    directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportSchemasForADSWizard.java
    directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ImportProjectsWizard.java

Modified: directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/PluginUtils.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/PluginUtils.java?rev=1211823&r1=1211822&r2=1211823&view=diff
==============================================================================
--- directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/PluginUtils.java (original)
+++ directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/PluginUtils.java Thu Dec  8 10:59:48 2011
@@ -405,7 +405,7 @@ public class PluginUtils
 
         if ( dialogMessage != null )
         {
-            ViewUtils.displayErrorMessageBox( ( ( dialogTitle == null ) ? "" : dialogTitle ), dialogMessage ); //$NON-NLS-1$
+            ViewUtils.displayErrorMessageDialog( ( ( dialogTitle == null ) ? "" : dialogTitle ), dialogMessage ); //$NON-NLS-1$
         }
     }
 
@@ -487,7 +487,7 @@ public class PluginUtils
                 catch ( CoreException e )
                 {
                     PluginUtils.logError( Messages.getString( "PluginUtils.ConnectorsLoadingError" ), e );
-                    ViewUtils.displayErrorMessageBox( Messages.getString( "PluginUtils.Error" ), Messages
+                    ViewUtils.displayErrorMessageDialog( Messages.getString( "PluginUtils.Error" ), Messages
                         .getString( "PluginUtils.ConnectorsLoadingError" ) );
                 }
             }

Modified: directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/HierarchyViewController.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/HierarchyViewController.java?rev=1211823&r1=1211822&r2=1211823&view=diff
==============================================================================
--- directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/HierarchyViewController.java (original)
+++ directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/HierarchyViewController.java Thu Dec  8 10:59:48 2011
@@ -134,7 +134,7 @@ public class HierarchyViewController
                 catch ( PartInitException e )
                 {
                     PluginUtils.logError( Messages.getString( "HierarchyViewController.ErrorOpeningEditor" ), e ); //$NON-NLS-1$
-                    ViewUtils.displayErrorMessageBox( Messages.getString( "HierarchyViewController.Error" ), Messages //$NON-NLS-1$
+                    ViewUtils.displayErrorMessageDialog( Messages.getString( "HierarchyViewController.Error" ), Messages //$NON-NLS-1$
                         .getString( "HierarchyViewController.ErrorOpeningEditor" ) ); //$NON-NLS-1$
                 }
             }

Modified: directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/ProblemsViewController.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/ProblemsViewController.java?rev=1211823&r1=1211822&r2=1211823&view=diff
==============================================================================
--- directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/ProblemsViewController.java (original)
+++ directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/ProblemsViewController.java Thu Dec  8 10:59:48 2011
@@ -160,7 +160,7 @@ public class ProblemsViewController
                     catch ( PartInitException e )
                     {
                         PluginUtils.logError( Messages.getString( "ProblemsViewController.ErrorOpeningEditor" ), e ); //$NON-NLS-1$
-                        ViewUtils.displayErrorMessageBox( Messages.getString( "ProblemsViewController.Error" ), //$NON-NLS-1$
+                        ViewUtils.displayErrorMessageDialog( Messages.getString( "ProblemsViewController.Error" ), //$NON-NLS-1$
                             Messages.getString( "ProblemsViewController.ErrorOpeningEditor" ) ); //$NON-NLS-1$
                     }
                 }

Modified: directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/SchemaViewController.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/SchemaViewController.java?rev=1211823&r1=1211822&r2=1211823&view=diff
==============================================================================
--- directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/SchemaViewController.java (original)
+++ directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/SchemaViewController.java Thu Dec  8 10:59:48 2011
@@ -537,7 +537,7 @@ public class SchemaViewController
                     catch ( PartInitException e )
                     {
                         PluginUtils.logError( Messages.getString( "SchemaViewController.ErrorOpeningEditor" ), e ); //$NON-NLS-1$
-                        ViewUtils.displayErrorMessageBox( Messages.getString( "SchemaViewController.error" ), Messages //$NON-NLS-1$
+                        ViewUtils.displayErrorMessageDialog( Messages.getString( "SchemaViewController.error" ), Messages //$NON-NLS-1$
                             .getString( "SchemaViewController.ErrorOpeningEditor" ) ); //$NON-NLS-1$
                     }
                 }

Modified: directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/actions/OpenElementAction.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/actions/OpenElementAction.java?rev=1211823&r1=1211822&r2=1211823&view=diff
==============================================================================
--- directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/actions/OpenElementAction.java (original)
+++ directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/actions/OpenElementAction.java Thu Dec  8 10:59:48 2011
@@ -92,7 +92,7 @@ public class OpenElementAction extends A
                 {
                     PluginUtils.logError( Messages.getString( "OpenElementAction.ErrorOpeningEditor" ), e ); //$NON-NLS-1$
                     ViewUtils
-                        .displayErrorMessageBox(
+                        .displayErrorMessageDialog(
                             Messages.getString( "OpenElementAction.Error" ), Messages.getString( "OpenElementAction.ErrorOpeningEditor" ) ); //$NON-NLS-1$ //$NON-NLS-2$
                 }
             }
@@ -108,7 +108,7 @@ public class OpenElementAction extends A
                 {
                     PluginUtils.logError( Messages.getString( "OpenElementAction.ErrorOpeningEditor" ), e ); //$NON-NLS-1$
                     ViewUtils
-                        .displayErrorMessageBox(
+                        .displayErrorMessageDialog(
                             Messages.getString( "OpenElementAction.Error" ), Messages.getString( "OpenElementAction.ErrorOpeningEditor" ) ); //$NON-NLS-1$ //$NON-NLS-2$
                 }
             }
@@ -123,7 +123,7 @@ public class OpenElementAction extends A
                 {
                     PluginUtils.logError( Messages.getString( "OpenElementAction.ErrorOpeningEditor" ), e ); //$NON-NLS-1$
                     ViewUtils
-                        .displayErrorMessageBox(
+                        .displayErrorMessageDialog(
                             Messages.getString( "OpenElementAction.Error" ), Messages.getString( "OpenElementAction.ErrorOpeningEditor" ) ); //$NON-NLS-1$ //$NON-NLS-2$
                 }
             }

Modified: directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/actions/OpenTypeHierarchyAction.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/actions/OpenTypeHierarchyAction.java?rev=1211823&r1=1211822&r2=1211823&view=diff
==============================================================================
--- directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/actions/OpenTypeHierarchyAction.java (original)
+++ directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/controller/actions/OpenTypeHierarchyAction.java Thu Dec  8 10:59:48 2011
@@ -167,7 +167,7 @@ public class OpenTypeHierarchyAction ext
             {
                 PluginUtils.logError( Messages.getString( "OpenTypeHierarchyAction.ErrorOpeningView" ), e ); //$NON-NLS-1$
                 ViewUtils
-                    .displayErrorMessageBox(
+                    .displayErrorMessageDialog(
                         Messages.getString( "OpenTypeHierarchyAction.Error" ), Messages.getString( "OpenTypeHierarchyAction.ErrorOpeningView" ) ); //$NON-NLS-1$ //$NON-NLS-2$
             }
         }

Modified: directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/ViewUtils.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/ViewUtils.java?rev=1211823&r1=1211822&r2=1211823&view=diff
==============================================================================
--- directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/editors/schema/SchemaEditorOverviewPage.java (original)
+++ directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/editors/schema/SchemaEditorOverviewPage.java Thu Dec  8 10:59:48 2011
@@ -153,7 +153,7 @@ public class SchemaEditorOverviewPage ex
                 catch ( PartInitException exception )
                 {
                     PluginUtils.logError( Messages.getString( "SchemaEditorOverviewPage.ErrorOpenEditor" ), exception ); //$NON-NLS-1$
-                    ViewUtils.displayErrorMessageBox( Messages.getString( "SchemaEditorOverviewPage.Error" ), Messages //$NON-NLS-1$
+                    ViewUtils.displayErrorMessageDialog( Messages.getString( "SchemaEditorOverviewPage.Error" ), Messages //$NON-NLS-1$
                         .getString( "SchemaEditorOverviewPage.ErrorOpenEditor" ) ); //$NON-NLS-1$
                 }
             }
@@ -182,7 +182,7 @@ public class SchemaEditorOverviewPage ex
                 catch ( PartInitException exception )
                 {
                     PluginUtils.logError( Messages.getString( "SchemaEditorOverviewPage.ErrorOpenEditor" ), exception ); //$NON-NLS-1$
-                    ViewUtils.displayErrorMessageBox( Messages.getString( "SchemaEditorOverviewPage.Error" ), Messages //$NON-NLS-1$
+                    ViewUtils.displayErrorMessageDialog( Messages.getString( "SchemaEditorOverviewPage.Error" ), Messages //$NON-NLS-1$
                         .getString( "SchemaEditorOverviewPage.ErrorOpenEditor" ) ); //$NON-NLS-1$
                 }
             }

Modified: directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/search/SearchPage.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/search/SearchPage.java?rev=1211823&r1=1211822&r2=1211823&view=diff
==============================================================================
--- directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/search/SearchPage.java (original)
+++ directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/search/SearchPage.java Thu Dec  8 10:59:48 2011
@@ -355,7 +355,7 @@ public class SearchPage extends DialogPa
         catch ( PartInitException e )
         {
             PluginUtils.logError( Messages.getString( "SearchPage.ErrorOpeningView" ), e ); //$NON-NLS-1$
-            ViewUtils.displayErrorMessageBox(
+            ViewUtils.displayErrorMessageDialog(
                 Messages.getString( "SearchPage.Error" ), Messages.getString( "SearchPage.ErrorOpeningView" ) ); //$NON-NLS-1$ //$NON-NLS-2$
         }
 

Modified: directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/views/SearchView.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/views/SearchView.java?rev=1211823&r1=1211822&r2=1211823&view=diff
==============================================================================
--- directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/views/SearchView.java (original)
+++ directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/views/SearchView.java Thu Dec  8 10:59:48 2011
@@ -574,7 +574,7 @@ public class SearchView extends ViewPart
                     {
                         PluginUtils.logError( Messages.getString( "SearchView.ErrorOpeningEditor" ), exception ); //$NON-NLS-1$
                         ViewUtils
-                            .displayErrorMessageBox(
+                            .displayErrorMessageDialog(
                                 Messages.getString( "SearchView.Error" ), Messages.getString( "SearchView.ErrorOpeningEditor" ) ); //$NON-NLS-1$ //$NON-NLS-2$
                     }
                 }

Modified: directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportProjectsWizard.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportProjectsWizard.java?rev=1211823&r1=1211822&r2=1211823&view=diff
==============================================================================
--- directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportProjectsWizard.java (original)
+++ directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportProjectsWizard.java Thu Dec  8 10:59:48 2011
@@ -109,7 +109,7 @@ public class ExportProjectsWizard extend
                                         .bind(
                                             Messages.getString( "ExportProjectsWizard.ErrorWhenSavingProject" ), new String[] { project.getName() } ), e ); //$NON-NLS-1$
                             ViewUtils
-                                .displayErrorMessageBox(
+                                .displayErrorMessageDialog(
                                     Messages.getString( "ExportProjectsWizard.Error" ), NLS.bind( Messages.getString( "ExportProjectsWizard.ErrorWhenSavingProject" ), new String[] { project.getName() } ) ); //$NON-NLS-1$ //$NON-NLS-2$
                         }
                         catch ( FileNotFoundException e )
@@ -120,7 +120,7 @@ public class ExportProjectsWizard extend
                                         .bind(
                                             Messages.getString( "ExportProjectsWizard.ErrorWhenSavingProject" ), new String[] { project.getName() } ), e ); //$NON-NLS-1$
                             ViewUtils
-                                .displayErrorMessageBox(
+                                .displayErrorMessageDialog(
                                     Messages.getString( "ExportProjectsWizard.Error" ), NLS.bind( Messages.getString( "ExportProjectsWizard.ErrorWhenSavingProject" ), new String[] { project.getName() } ) ); //$NON-NLS-1$ //$NON-NLS-2$
                         }
                         catch ( IOException e )
@@ -131,7 +131,7 @@ public class ExportProjectsWizard extend
                                         .bind(
                                             Messages.getString( "ExportProjectsWizard.ErrorWhenSavingProject" ), new String[] { project.getName() } ), e ); //$NON-NLS-1$
                             ViewUtils
-                                .displayErrorMessageBox(
+                                .displayErrorMessageDialog(
                                     Messages.getString( "ExportProjectsWizard.Error" ), NLS.bind( Messages.getString( "ExportProjectsWizard.ErrorWhenSavingProject" ), new String[] { project.getName() } ) ); //$NON-NLS-1$ //$NON-NLS-2$
                         }
                         monitor.worked( 1 );

Modified: directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportSchemasAsOpenLdapWizard.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportSchemasAsOpenLdapWizard.java?rev=1211823&r1=1211822&r2=1211823&view=diff
==============================================================================
--- directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportSchemasAsOpenLdapWizard.java (original)
+++ directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportSchemasAsOpenLdapWizard.java Thu Dec  8 10:59:48 2011
@@ -105,7 +105,7 @@ public class ExportSchemasAsOpenLdapWiza
                                             Messages.getString( "ExportSchemasAsOpenLdapWizard.ErrorSavingSchema" ), new String[] { schema.getSchemaName() } ), //$NON-NLS-1$
                                     e );
                             ViewUtils
-                                .displayErrorMessageBox(
+                                .displayErrorMessageDialog(
                                     Messages.getString( "ExportSchemasAsOpenLdapWizard.Error" ), NLS.bind( Messages.getString( "ExportSchemasAsOpenLdapWizard.ErrorSavingSchema" ), new String[] { schema.getSchemaName() } ) ); //$NON-NLS-1$ //$NON-NLS-2$
                         }
                         monitor.worked( 1 );

Modified: directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportSchemasAsXmlWizard.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportSchemasAsXmlWizard.java?rev=1211823&r1=1211822&r2=1211823&view=diff
==============================================================================
--- directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportSchemasAsXmlWizard.java (original)
+++ directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportSchemasAsXmlWizard.java Thu Dec  8 10:59:48 2011
@@ -107,7 +107,7 @@ public class ExportSchemasAsXmlWizard ex
                                             .bind(
                                                 Messages.getString( "ExportSchemasAsXmlWizard.ErrorWhenSavingSchema" ), new String[] { schema.getSchemaName() } ), e ); //$NON-NLS-1$
                                 ViewUtils
-                                    .displayErrorMessageBox(
+                                    .displayErrorMessageDialog(
                                         Messages.getString( "ExportSchemasAsXmlWizard.Error" ), NLS.bind( Messages.getString( "ExportSchemasAsXmlWizard.ErrorWhenSavingSchema" ), new String[] { schema.getSchemaName() } ) ); //$NON-NLS-1$ //$NON-NLS-2$
                             }
                             monitor.worked( 1 );
@@ -146,7 +146,7 @@ public class ExportSchemasAsXmlWizard ex
                             PluginUtils.logError( Messages
                                 .getString( "ExportSchemasAsXmlWizard.ErrorWhenSavingSchemas" ), e ); //$NON-NLS-1$
                             ViewUtils
-                                .displayErrorMessageBox(
+                                .displayErrorMessageDialog(
                                     Messages.getString( "ExportSchemasAsXmlWizard.Error" ), Messages.getString( "ExportSchemasAsXmlWizard.ErrorWhenSavingSchemas" ) ); //$NON-NLS-1$ //$NON-NLS-2$
                         }
                         monitor.worked( 1 );

Modified: directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportSchemasForADSWizard.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportSchemasForADSWizard.java?rev=1211823&r1=1211822&r2=1211823&view=diff
==============================================================================
--- directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportSchemasForADSWizard.java (original)
+++ directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ExportSchemasForADSWizard.java Thu Dec  8 10:59:48 2011
@@ -133,7 +133,7 @@ public class ExportSchemasForADSWizard e
                                             .bind(
                                                 Messages.getString( "ExportSchemasForADSWizard.ErrorSavingSchema" ), new String[] { schema.getSchemaName() } ), e ); //$NON-NLS-1$
                                 ViewUtils
-                                    .displayErrorMessageBox(
+                                    .displayErrorMessageDialog(
                                         Messages.getString( "ExportSchemasForADSWizard.Error" ), NLS.bind( Messages.getString( "ExportSchemasForADSWizard.ErrorSavingSchema" ), new String[] { schema.getSchemaName() } ) ); //$NON-NLS-1$ //$NON-NLS-2$
                             }
                             monitor.worked( 1 );
@@ -184,7 +184,7 @@ public class ExportSchemasForADSWizard e
                                             .bind(
                                                 Messages.getString( "ExportSchemasForADSWizard.ErrorSavingSchema" ), new String[] { schema.getSchemaName() } ), e ); //$NON-NLS-1$
                                 ViewUtils
-                                    .displayErrorMessageBox(
+                                    .displayErrorMessageDialog(
                                         Messages.getString( "ExportSchemasForADSWizard.Error" ), NLS.bind( Messages.getString( "ExportSchemasForADSWizard.ErrorSavingSchema" ), new String[] { schema.getSchemaName() } ) ); //$NON-NLS-1$ //$NON-NLS-2$
                             }
                         }
@@ -200,7 +200,7 @@ public class ExportSchemasForADSWizard e
                             PluginUtils.logError(
                                 Messages.getString( "ExportSchemasForADSWizard.ErrorSavingSchemas" ), e ); //$NON-NLS-1$
                             ViewUtils
-                                .displayErrorMessageBox(
+                                .displayErrorMessageDialog(
                                     Messages.getString( "ExportSchemasForADSWizard.Error" ), Messages.getString( "ExportSchemasForADSWizard.ErrorSavingSchemas" ) ); //$NON-NLS-1$ //$NON-NLS-2$
                         }
                         monitor.worked( 1 );

Modified: directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ImportProjectsWizard.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ImportProjectsWizard.java?rev=1211823&r1=1211822&r2=1211823&view=diff
==============================================================================
--- directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ImportProjectsWizard.java (original)
+++ directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/wizards/ImportProjectsWizard.java Thu Dec  8 10:59:48 2011
@@ -104,7 +104,7 @@ public class ImportProjectsWizard extend
                                         .bind(
                                             Messages.getString( "ImportProjectsWizard.ErrorImportingProject" ), new String[] { projectFile.getName() } ), e ); //$NON-NLS-1$
                             ViewUtils
-                                .displayErrorMessageBox(
+                                .displayErrorMessageDialog(
                                     Messages.getString( "ImportProjectsWizard.ImportError" ), //$NON-NLS-1$
                                     NLS
                                         .bind(
@@ -118,7 +118,7 @@ public class ImportProjectsWizard extend
                                         .bind(
                                             Messages.getString( "ImportProjectsWizard.ErrorImportingProject" ), new String[] { projectFile.getName() } ), e ); //$NON-NLS-1$
                             ViewUtils
-                                .displayErrorMessageBox(
+                                .displayErrorMessageDialog(
                                     Messages.getString( "ImportProjectsWizard.ImportError" ), //$NON-NLS-1$
                                     NLS
                                         .bind(
--- directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/ViewUtils.java (original)
+++ directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/ViewUtils.java Thu Dec  8 10:59:48 2011
@@ -22,9 +22,9 @@ package org.apache.directory.studio.sche
 
 import java.util.List;
 
+import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.Color;
-import org.eclipse.swt.widgets.MessageBox;
 import org.eclipse.ui.PlatformUI;
 
 
@@ -85,94 +85,73 @@ public class ViewUtils
 
 
     /**
      * Displays an Error Message Box with the given title and message.
      *
-     * @param title
-     *      the title of the window
-     * @param message
-     *      the message to display
-     * @return
-     *      the ID of the button that was selected to dismiss 
-     *      the message box (e.g. SWT.OK, SWT.CANCEL, etc...)
+     * @param title the title of the window
+     * @param message the message to display
+     * @return <code>true</code> if the user presses the OK or Yes button,
+     *         <code>false</code> otherwise
      */
-    public static int displayErrorMessageBox( String title, String message )
+    public static boolean displayErrorMessageDialog( String title, String message )
     {
-        return displayMessageBox( SWT.OK | SWT.ICON_ERROR, title, message );
+        return displayMessageDialog( MessageDialog.ERROR, title, message );
     }
 
 
     /**
      * Displays a Information Message Box with the given title and message.
      *
-     * @param title
-     *      the title of the window
-     * @param message
-     *      the message to display
-     * @return
-     *      the ID of the button that was selected to dismiss 
-     *      the message box (e.g. SWT.OK, SWT.CANCEL, etc...)
+     * @param title the title of the window
+     * @param message the message to display
+     * @return <code>true</code> if the user presses the OK or Yes button,
+     *         <code>false</code> otherwise
      */
-    public static int displayWarningMessageBox( String title, String message )
+    public static boolean displayWarningMessageDialog( String title, String message )
     {
-        return displayMessageBox( SWT.OK | SWT.ICON_WARNING, title, message );
+        return displayMessageDialog( MessageDialog.WARNING, title, message );
     }
 
 
     /**
      * Displays a Information Message Box with the given title and message.
      *
-     * @param title
-     *      the title of the window
-     * @param message
-     *      the message to display
-     * @return
-     *      the ID of the button that was selected to dismiss 
-     *      the message box (e.g. SWT.OK, SWT.CANCEL, etc...)
+     * @param title the title of the window
+     * @param message the message to display
+     * @return <code>true</code> if the user presses the OK or Yes button,
+     *         <code>false</code> otherwise
      */
-    public static int displayInformationMessageBox( String title, String message )
+    public static boolean displayInformationMessageDialog( String title, String message )
     {
-        return displayMessageBox( SWT.OK | SWT.ICON_INFORMATION, title, message );
+        return displayMessageDialog( MessageDialog.INFORMATION, title, message );
     }
 
 
     /**
-     * Displays a Information Question Box with the given title and message.
-     *
-     * @param buttonStyle
-     *      the style of the buttons of the dialog (e.g. SWT.OK, SWT.CANCEL, etc...)
-     * @param title
-     *      the title of the window
-     * @param message
-     *      the message to display
-     * @return
-     *      the ID of the button that was selected to dismiss 
-     *      the message box (e.g. SWT.OK, SWT.CANCEL, etc...)
+     * Displays a Information Question message dialog with the given title and message.
+     * 
+     * @param title the title of the window
+     * @param message the message to display
+     * @return <code>true</code> if the user presses the OK or Yes button,
+     *         <code>false</code> otherwise
      */
-    public static int displayQuestionMessageBox( int buttonStyle, String title, String message )
+    public static boolean displayQuestionMessageDialog( String title, String message )
     {
-        return displayMessageBox( SWT.ICON_QUESTION | buttonStyle, title, message );
+        return displayMessageDialog( MessageDialog.QUESTION, title, message );
     }
 
 
     /**
      * Displays a Message Box with the given style, title and message.
      *
      * @param style
      *      the style of dialog
      * @param title
      *      the title of the window
      * @param message
      *      the message to display
      * @return
      *      the ID of the button that was selected to dismiss 
      *      the message box (e.g. SWT.OK, SWT.CANCEL, etc...)
      */
-    private static int displayMessageBox( int style, String title, String message )
+    private static boolean displayMessageDialog( int kind, String title, String message )
     {
-        MessageBox messageBox = new MessageBox( PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell(), style );
-        messageBox.setText( title );
-        messageBox.setMessage( message );
-        return messageBox.open();
+        return MessageDialog.open( kind, PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell(), title,
+            message, SWT.NONE );
     }
-
 }
@@ -85,94 +85,73 @@ public class ViewUtils
 
     /**
-     * Displays an Error Message Box with the given title and message.
+     * Displays an error message dialog with the given title and message.
      *
@@ -85,94 +85,73 @@ public class ViewUtils
 
     /**
-     * Displays a Information Message Box with the given title and message.
+     * Displays a warning message dialog with the given title and message.
      *
@@ -85,94 +85,73 @@ public class ViewUtils
 
     /**
-     * Displays a Information Message Box with the given title and message.
+     * Displays a information message dialog with the given title and message.
      *
@@ -85,94 +85,73 @@ public class ViewUtils
 
     /**
-     * Displays a Message Box with the given style, title and message.
+     * Displays a message dialog with the given style, title and message.
      *
@@ -85,94 +85,73 @@ public class ViewUtils
      *
-     * @param style
-     *      the style of dialog
-     * @param title
-     *      the title of the window
-     * @param message
-     *      the message to display
-     * @return
-     *      the ID of the button that was selected to dismiss 
-     *      the message box (e.g. SWT.OK, SWT.CANCEL, etc...)
+     * @param kind the kind of dialog
+     * @param title the title of the window
+     * @param message the message to display
+     * @return <code>true</code> if the user presses the OK or Yes button,
+     *         <code>false</code> otherwise
      */

Modified: directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/editors/schema/SchemaEditorOverviewPage.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/schemaeditor/src/main/java/org/apache/directory/studio/schemaeditor/view/editors/schema/SchemaEditorOverviewPage.java?rev=1211823&r1=1211822&r2=1211823&view=diff
==============================================================================